@@ -1,8 +1,7 @@
 package Term::YAP;
+$Term::YAP::VERSION = '0.07';
 use strict;
 use warnings;
-use Carp;
-our $VERSION = '0.06'; # VERSION
 
 =head1 NAME
 
@@ -18,21 +17,19 @@ use namespace::clean 0.26;
 =head1 SYNOPSIS
 
     use Term::YAP;
-	
-	my $yap = Term::YAP->new( { name => 'Checking', rotate => 0, time => 1 } );
-	
+    my $yap = Term::YAP->new( { name => 'Checking', rotate => 0, time => 1 } );
     $yap->start(); # start the pulse
     # do something between
     $yap->stop() # stop it
 
 =head1 DESCRIPTION
 
-Term::YAP is a L<Moo> based class to implement a "pulse" bar in a terminal. A pulse bar does not shows any progress of the task being executed
-but at least shows that the program is working instead of showing nothing for user.
+Term::YAP is a L<Moo> based class to implement a "pulse" bar in a terminal. A pulse bar doesn't actually keep track of progress from any task being executed
+but at least shows that the program is working instead of nothing for the end user.
 
 This is the parent class and some methods were not implemented, you probably want to look for subclasses to get an implementation.
 
-This module was shamelessly copied from L<Term::Pulse>. Sorry, couldn't get my bug/patch approved. :-)
+This module started as a shamelessly copy from L<Term::Pulse>, nowadays it keeps the same features but with a different implementation.
 
 =head1 EXPORT
 
@@ -145,9 +142,12 @@ Install handlers for signals C<INT> and C<__DIE__>.
 =cut
 
 sub BUILD {
+
     my $self = shift;
+
     $SIG{INT}     = sub { $self->stop };
     $SIG{__DIE__} = sub { $self->stop };
+
 }
 
 =head2 get_name
@@ -181,17 +181,25 @@ Setter for the C<debug> attribute.
 =cut
 
 sub start {
-    return shift->is_running();
+
+    my $self = shift;
+    return $self->is_running();
+
 }
 
 sub _is_enough {
-    confess '_is_enough() method must be overrided by subclasses of Term::YAP';
+
+    die '_is_enough() method must be overrided by subclasses of Term::YAP';
+
 }
 
 sub _keep_pulsing {
+
     my $self = shift;
+
     my @mark = qw(- \ | / - \ | /);
     $| = 1;
+
     my $name   = $self->get_name();
     my $rotate = $self->is_rotatable();
     my $size   = $self->get_size();
@@ -203,6 +211,7 @@ sub _keep_pulsing {
 
         # forward
         foreach my $index ( 1 .. $size ) {
+
             my $mark = $rotate ? $mark[ $index % 8 ] : q{=};
             printf "$name...[%s%s%s]", q{ } x ( $index - 1 ), $mark,
               q{ } x ( $size - $index );
@@ -214,6 +223,7 @@ sub _keep_pulsing {
 
         # backward
         foreach my $index ( 1 .. $size ) {
+
             my $mark = $rotate ? $mark[ ( $index % 8 ) * -1 ] : q{=};
             printf "$name...[%s%s%s]", q{ } x ( $size - $index ), $mark,
               q{ } x ( $index - 1 );
@@ -221,6 +231,7 @@ sub _keep_pulsing {
             printf "\r";
             last INFINITE if ( $self->_is_enough() );
             $self->_sleep();
+
         }
 
     }
@@ -240,9 +251,18 @@ sub stop {
 }
 
 sub _report {
-    my $self = shift;
-    printf "%s%sDone%s\n", $self->get_name(), q{.} x ( $self->get_size + 1 ), ' ';
-    return 1;
+    my $self   = shift;
+    my $name   = $self->get_name();
+    my $length = length($name);
+
+    if ( $length > 0 ) {
+        printf "$name%sDone%s\n", q{.} x ( 35 - $length ), q{ } x 43;
+        return 1;
+    }
+    else {
+        warn "cannot print progress without positive length for '$name'";
+        return 0;
+    }
 }
 
 sub _sleep {
